@@ -2,7 +2,7 @@
  * This file is part of gtatool, a tool to manipulate Generic Tagged Arrays
  * (GTAs).
  *
- * Copyright (C) 2005, 2006, 2007, 2008, 2009, 2010, 2011
+ * Copyright (C) 2005, 2006, 2007, 2008, 2009, 2010, 2011, 2012
  * Martin Lambers <marlam@marlam.de>
  *
  * This program is free software; you can redistribute it and/or modify
@@ -93,6 +93,7 @@ CMD_DECL(dimension_reverse)
 CMD_DECL(dimension_split)
 CMD_DECL(extract)
 CMD_DECL(fill)
+CMD_DECL(from_csv)
 CMD_DECL(from_dcmtk)
 CMD_DECL(from_exr)
 CMD_DECL(from_ffmpeg)
@@ -106,6 +107,7 @@ CMD_DECL(from_ply)
 CMD_DECL(from_rat)
 CMD_DECL(from_raw)
 CMD_DECL(from_sndfile)
+CMD_DECL(from_teem)
 CMD_DECL(gui)
 CMD_DECL(help)
 CMD_DECL(info)
@@ -116,6 +118,7 @@ CMD_DECL(stream_extract)
 CMD_DECL(stream_merge)
 CMD_DECL(stream_split)
 CMD_DECL(tag)
+CMD_DECL(to_csv)
 CMD_DECL(to_exr)
 CMD_DECL(to_gdal)
 CMD_DECL(to_magick)
@@ -127,6 +130,7 @@ CMD_DECL(to_ply)
 CMD_DECL(to_rat)
 CMD_DECL(to_raw)
 CMD_DECL(to_sndfile)
+CMD_DECL(to_teem)
 CMD_DECL(uncompress)
 CMD_DECL(version)
 
@@ -151,6 +155,7 @@ static cmd_t cmds[] =
     CMD("dimension-split",   dimension,  dimension_split,   true,          BUILTIN),
     CMD("extract",           array,      extract,           true,          BUILTIN),
     CMD("fill",              array,      fill,              true,          BUILTIN),
+    CMD("from-csv",          conversion, from_csv,          WITH_CSV,      "conv-csv"),
     CMD("from-dcmtk",        conversion, from_dcmtk,        WITH_DCMTK,    "conv-dcmtk"),
     CMD("from-exr",          conversion, from_exr,          WITH_EXR,      "conv-exr"),
     CMD("from-ffmpeg",       conversion, from_ffmpeg,       WITH_FFMPEG,   "conv-ffmpeg"),
@@ -164,6 +169,7 @@ static cmd_t cmds[] =
     CMD("from-rat",          conversion, from_rat,          WITH_RAT,      "conv-rat"),
     CMD("from-raw",          conversion, from_raw,          WITH_RAW,      "conv-raw"),
     CMD("from-sndfile",      conversion, from_sndfile,      WITH_SNDFILE,  "conv-sndfile"),
+    CMD("from-teem",         conversion, from_teem,         WITH_TEEM,     "conv-teem"),
     CMD("gui",               misc,       gui,               WITH_QT,       "gui"),
     CMD("help",              misc,       help,              true,          BUILTIN),
     CMD("info",              array,      info,              true,          BUILTIN),
@@ -174,6 +180,7 @@ static cmd_t cmds[] =
     CMD("stream-merge",      stream,     stream_merge,      true,          BUILTIN),
     CMD("stream-split",      stream,     stream_split,      true,          BUILTIN),
     CMD("tag",               array,      tag,               true,          BUILTIN),
+    CMD("to-csv",            conversion, to_csv,            WITH_CSV,      "conv-csv"),
     CMD("to-exr",            conversion, to_exr,            WITH_EXR,      "conv-exr"),
     CMD("to-gdal",           conversion, to_gdal,           WITH_GDAL,     "conv-gdal"),
     CMD("to-magick",         conversion, to_magick,         WITH_MAGICK,   "conv-magick"),
@@ -185,6 +192,7 @@ static cmd_t cmds[] =
     CMD("to-rat",            conversion, to_rat,            WITH_RAT,      "conv-rat"),
     CMD("to-raw",            conversion, to_raw,            WITH_RAW,      "conv-raw"),
     CMD("to-sndfile",        conversion, to_sndfile,        WITH_SNDFILE,  "conv-sndfile"),
+    CMD("to-teem",           conversion, to_teem,           WITH_TEEM,     "conv-teem"),
     CMD("uncompress",        array,      uncompress,        true,          BUILTIN),
     CMD("version",           misc,       version,           true,          BUILTIN),
 };
