@@ -551,6 +551,13 @@ GUI::GUI()
     file_menu->addAction(file_close_all_action);
     file_menu->addSeparator();
     QMenu *file_import_menu = file_menu->addMenu(tr("Import"));
+    QAction *file_import_csv_action = new QAction(tr("CSV data..."), this);
+    connect(file_import_csv_action, SIGNAL(triggered()), this, SLOT(file_import_csv()));
+    if (!cmd_is_available(cmd_find("from-csv")))
+    {
+        file_import_csv_action->setEnabled(false);
+    }
+    file_import_menu->addAction(file_import_csv_action);
     QAction *file_import_dcmtk_action = new QAction(tr("DICOM files (via DCMTK)..."), this);
     connect(file_import_dcmtk_action, SIGNAL(triggered()), this, SLOT(file_import_dcmtk()));
     if (!cmd_is_available(cmd_find("from-dcmtk")))
@@ -616,11 +623,40 @@ GUI::GUI()
     file_import_menu->addAction(file_import_ply_action);
     QAction *file_import_rat_action = new QAction(tr("RAT RadarTools data..."), this);
     connect(file_import_rat_action, SIGNAL(triggered()), this, SLOT(file_import_rat()));
+    if (!cmd_is_available(cmd_find("from-rat")))
+    {
+        file_import_rat_action->setEnabled(false);
+    }
     file_import_menu->addAction(file_import_rat_action);
     QAction *file_import_raw_action = new QAction(tr("Raw data..."), this);
     connect(file_import_raw_action, SIGNAL(triggered()), this, SLOT(file_import_raw()));
+    if (!cmd_is_available(cmd_find("from-raw")))
+    {
+        file_import_raw_action->setEnabled(false);
+    }
     file_import_menu->addAction(file_import_raw_action);
+    QAction *file_import_sndfile_action = new QAction(tr("Audio data (via sndfile)..."), this);
+    connect(file_import_sndfile_action, SIGNAL(triggered()), this, SLOT(file_import_sndfile()));
+    if (!cmd_is_available(cmd_find("from-sndfile")))
+    {
+        file_import_sndfile_action->setEnabled(false);
+    }
+    file_import_menu->addAction(file_import_sndfile_action);
+    QAction *file_import_teem_action = new QAction(tr("NRRD data (via teem)..."), this);
+    connect(file_import_teem_action, SIGNAL(triggered()), this, SLOT(file_import_teem()));
+    if (!cmd_is_available(cmd_find("from-teem")))
+    {
+        file_import_teem_action->setEnabled(false);
+    }
+    file_import_menu->addAction(file_import_teem_action);
     QMenu *file_export_menu = file_menu->addMenu(tr("Export"));
+    QAction *file_export_csv_action = new QAction(tr("CSV data..."), this);
+    connect(file_export_csv_action, SIGNAL(triggered()), this, SLOT(file_export_csv()));
+    if (!cmd_is_available(cmd_find("to-csv")))
+    {
+        file_export_csv_action->setEnabled(false);
+    }
+    file_export_menu->addAction(file_export_csv_action);
     QAction *file_export_exr_action = new QAction(tr("EXR HDR images (via EXR)..."), this);
     connect(file_export_exr_action, SIGNAL(triggered()), this, SLOT(file_export_exr()));
     if (!cmd_is_available(cmd_find("to-exr")))
@@ -672,10 +708,32 @@ GUI::GUI()
     file_export_menu->addAction(file_export_ply_action);
     QAction *file_export_rat_action = new QAction(tr("RAT RadarTools data..."), this);
     connect(file_export_rat_action, SIGNAL(triggered()), this, SLOT(file_export_rat()));
+    if (!cmd_is_available(cmd_find("to-rat")))
+    {
+        file_export_rat_action->setEnabled(false);
+    }
     file_export_menu->addAction(file_export_rat_action);
     QAction *file_export_raw_action = new QAction(tr("Raw data..."), this);
     connect(file_export_raw_action, SIGNAL(triggered()), this, SLOT(file_export_raw()));
+    if (!cmd_is_available(cmd_find("to-raw")))
+    {
+        file_export_raw_action->setEnabled(false);
+    }
     file_export_menu->addAction(file_export_raw_action);
+    QAction *file_export_sndfile_action = new QAction(tr("WAV audio (via sndfile)..."), this);
+    connect(file_export_sndfile_action, SIGNAL(triggered()), this, SLOT(file_export_sndfile()));
+    if (!cmd_is_available(cmd_find("to-sndfile")))
+    {
+        file_export_sndfile_action->setEnabled(false);
+    }
+    file_export_menu->addAction(file_export_sndfile_action);
+    QAction *file_export_teem_action = new QAction(tr("NRRD data (via teem)..."), this);
+    connect(file_export_teem_action, SIGNAL(triggered()), this, SLOT(file_export_teem()));
+    if (!cmd_is_available(cmd_find("to-teem")))
+    {
+        file_export_teem_action->setEnabled(false);
+    }
+    file_export_menu->addAction(file_export_teem_action);
     file_menu->addSeparator();
     QAction *quit_action = new QAction(tr("&Quit"), this);
     quit_action->setShortcut(tr("Ctrl+Q"));
@@ -1380,6 +1438,11 @@ void GUI::file_close_all()
     }
 }
 
+void GUI::file_import_csv()
+{
+    import_from("from-csv", std::vector<std::string>(), QStringList("CSV files (*.csv)"));
+}
+
 void GUI::file_import_dcmtk()
 {
     import_from("from-dcmtk", std::vector<std::string>(), QStringList("DICOM files (*.dcm)"));
@@ -1473,6 +1536,21 @@ void GUI::file_import_raw()
     import_from("from-raw", options, QStringList("Raw files (*.raw *.dat)"));
 }
 
+void GUI::file_import_sndfile()
+{
+    import_from("from-sndfile", std::vector<std::string>(), QStringList("WAV files (*.wav)"));
+}
+
+void GUI::file_import_teem()
+{
+    import_from("from-teem", std::vector<std::string>(), QStringList("NRRD files (*.nrrd)"));
+}
+
+void GUI::file_export_csv()
+{
+    export_to("to-csv", std::vector<std::string>(), "csv", QStringList("CSV files (*.csv)"));
+}
+
 void GUI::file_export_exr()
 {
     export_to("to-exr", std::vector<std::string>(), "exr", QStringList("EXR files (*.exr)"));
@@ -1546,6 +1624,16 @@ void GUI::file_export_raw()
     export_to("to-raw", options, "raw", QStringList("Raw files (*.raw *.dat)"));
 }
 
+void GUI::file_export_sndfile()
+{
+    export_to("to-sndfile", std::vector<std::string>(), "wav", QStringList("WAV files (*.wav)"));
+}
+
+void GUI::file_export_teem()
+{
+    export_to("to-teem", std::vector<std::string>(), "nrrd", QStringList("NRRD files (*.nrrd)"));
+}
+
 void GUI::stream_merge()
 {
     if (!check_have_file() || !check_all_files_unchanged())
@@ -2183,7 +2271,7 @@ void GUI::component_convert()
     layout->addWidget(comp_label, 0, 0, 1, 2);
     QLineEdit *comp_edit = new QLineEdit("");
     layout->addWidget(comp_edit, 1, 0, 1, 2);
-    QCheckBox *n_checkbox = new QCheckBox("Normalize integers when converting to floating point");
+    QCheckBox *n_checkbox = new QCheckBox("Normalize when converting between integers and floating point");
     layout->addWidget(n_checkbox, 2, 0, 1, 2);
     QPushButton *ok_btn = new QPushButton(tr("&OK"));
     ok_btn->setDefault(true);
@@ -2348,8 +2436,8 @@ void GUI::help_about()
 {
     QMessageBox::about(this, tr("About " PACKAGE_NAME), tr(
                 "<p>This is %1 version %2, using libgta version %3.</p>"
-                "<p>This graphical user interface is a frontend for the command line interface of this tool. "
-                "It provides only a limited subset of the full functionality.</p>"
+                "<p>This graphical user interface is a frontend for the command line interface of this tool, "
+                "and provides only a limited subset of the full functionality.</p>"
                 "<p>Use <code>%4 help</code> to get a list of all commands provided by this tool, "
                 "and <code>%4 help &lt;cmd&gt;</code> to get a description of a specific command.</p>"
                 "<p>See <a href=\"%5\">%5</a> for more information on this software.</p>"
